@@ -1,11 +1,11 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import ModelSQL, fields
 from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 
 
 __all__ = ['InvoiceLineStockMove', 'InvoiceLine']
-__metaclass__ = PoolMeta
 
 
 class InvoiceLineStockMove(ModelSQL):
@@ -13,15 +13,19 @@ class InvoiceLineStockMove(ModelSQL):
     __name__ = 'account.invoice.line-stock.move'
 
     invoice_line = fields.Many2One('account.invoice.line', 'Invoice Line',
-        required=True, select=True)
+        required=True, select=True, ondelete='CASCADE')
     stock_move = fields.Many2One('stock.move', 'Stock Move', required=True,
-        select=True)
+        select=True, ondelete='CASCADE')
 
 
-class InvoiceLine:
+class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
     stock_moves = fields.Many2Many('account.invoice.line-stock.move',
-        'invoice_line', 'stock_move', 'Stock Moves')
+        'invoice_line', 'stock_move', 'Stock Moves',
+        states={
+            'invisible': Eval('type') != 'line',
+            },
+        depends=['type'])
 
     @property
     def moved_quantity(self):
